##  Accessing Joule
In SAP LeanIX, you can open the Joule panel by clicking the diamond-shaped button located in the upper-right corner, next to the user profile menu.
![Accessing Joule](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275804397a44101489fbb08c4425f047_LowRes.png)
Accessing Joule
In the resultant panel, you can start a conversation with Joule, or select available actions to search and access different resources.
YesNo
Send
